chop.image
==========

.. automodule:: chop.image

   
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      group_patches
      matplotlib_imshow
      matplotlib_imshow_batch
      normalize_image
   
   

   
   
   

   
   
   



